import LocaleService from './Locale.service';
import { reactive } from 'vue';

export const state = reactive({
    data: null
});

export const getters = {
    get data_local() {
        return getters.localeData();
    },
    get widget() {
        let data = getters.localeData();
        if (!data || !data.widget) return null;
        return data.widget[0];
    },
    localeData(id) {
        let data = state.data;
        let locale = id || LocaleService.getters.selectedLocale ? LocaleService.getters.selectedLocale.id : null;
        return data && locale ? data[locale] : null;
    },
    assetPath(url) {
        if (!url) return null;
        if (url.indexOf(':/') != -1) return url;
        return process.env.VUE_APP_ASSET_URL.replace('{url}', url);
    },

    global(id, lang) {
        let data = getters.localeData(lang);
        if (!data || !data.global || data.global.length < 1) return null;
        return Reflect.get(data.global[0], id);
    },

    field(id, lang) {
        let data = getters.localeData(lang);
        if (!data) return null;
        return Reflect.get(data, id);
    }
}
export const mutations = {
    init() {
        return new Promise((resolve, reject) => {
            console.debug('Loading data from: ', process.env.VUE_APP_DATA_URL);
            fetch(process.env.VUE_APP_DATA_URL)
                .then((response) => {
                    console.debug('Data successfully loaded, parsing as JSON: ', response);
                    return response.json();
                })
                .then((response) => {
                    state.data = response;
                    console.debug('Data parsed successfully: ', response);
                    resolve();
                })
                .catch((err) => {
                    console.debug('Data load/parse failed: ', err);
                    reject(err)
                })
        });
    }
}

export default {
    state,
    getters,
    mutations
}