import { reactive } from 'vue';

export const defs = {
    all: [
        {
            id: 'ar',
            label: 'language_arabic',
            rtl: true
        },
        {
            id: 'default',
            label: 'language_default',
            default: true,
            rtl: false
        }
    ]
};

export const state = reactive({
    selected: null
});

export const getters = {
    get selectedLocale() {
        return defs.all.find((t) => t.id == state.selected);
    },
    get selectedLocaleRtl() {
        return getters.selectedLocale
            ? getters.selectedLocale.rtl
            : null;
    },
    get defaultLocale() {
        return defs.all.find((t) => t.default) || defs.all[0];
    }
};

export const mutations = {
    init() {
        return new Promise((resolve, reject) => {
            try {
                mutations.select(getters.defaultLocale.id);
            } catch (e) {
                reject(e);
                return;
            }
            resolve();
        });
    },
    select(id) {
        id = (id.id || id); // unwrap locale object if used
        state.selected = id;
    },
    alternateLocales() {
        let index = defs.all.findIndex((l) => l.id == state.selected);
        if (index == defs.all.length - 1) index = 0;
        else index++;
        mutations.select(defs.all[index]);
    }
}



export default {
    defs,
    state,
    getters,
    mutations
}
