import { reactive } from 'vue';
import DataService from "./Data.service";
import LocaleService from "./Locale.service";
import ConfigService from "./Config.service";

export const defs = {
    SUCCESS: 'success',
    FAIL: 'fail',
}

export const state = reactive({
    tasks: [
        {
            label: "Config",
            state: null,
            error: null,
            startup: ConfigService.mutations.init
        },
        {
            label: "Locales",
            state: null,
            error: null,
            startup: LocaleService.mutations.init
        },
        {
            label: "CMS Content",
            state: null,
            error: null,
            startup: DataService.mutations.init
        },
    ],
    loaded: false
});

export const getters = {
    getTask(label) {
        return state.tasks.find((t) => t.label == label);
    }
}

function assessLoaded() {
    let loaded = true;
    for (let task of state.tasks) {
        if (task.state != defs.SUCCESS) {
            loaded = false;
            break;
        }
    }
    state.loaded = loaded;
}

export const mutations = {
    startup() {
        for (let task of state.tasks) {
            task.startup()
                .then(() => {
                    task.state = defs.SUCCESS;
                    assessLoaded();
                })
                .catch((err) => {
                    task.error = err;
                    task.state = defs.FAIL;
                    assessLoaded();
                });
        }
    }
}

export default {
    state,
    getters,
    mutations
}