import { reactive } from 'vue';

export const state = reactive({
    endpoint: null,
    refresh_mins: null,
    location: null,
    weather: null,
});

let refreshTimer;
function clearRefreshTimer() {
    if (refreshTimer != null) {
        clearTimeout(refreshTimer);
        refreshTimer = null;
    }
}
function startRefreshTimer() {
    clearRefreshTimer();
    if (!state.refresh_mins) return;
    refreshTimer = setTimeout(() => loadWeather(), state.refresh_mins * 60 * 1000);
}
function loadWeather() {
    clearRefreshTimer();

    if (!state.endpoint) return;

    fetch(state.endpoint, {
        method: 'GET'
    }).then(res => {
        if (!res.ok) {
            console.error('Failed to load weather: ', res);
        } else {
            console.log('Weather loaded: ', res);

            res.json().then((res) => {
                console.log('Weather parsed: ', res);
                state.location = res.location;
                state.weather = res.current;

            }).catch((err) => {
                console.log('Failed to parse weather response: ', err);
            });
        }
        startRefreshTimer();
    }).catch(err => {
        console.error('Error loading weather: ', err);
        startRefreshTimer();
    });
}

export const mutations = {
    setEndpoint(url) {
        if (state.endpoint == url) return;
        state.endpoint = url;
        loadWeather();
    },
    setRefreshMins(mins) {
        if (state.refresh_mins == mins) return;
        state.refresh_mins = mins;
        if (refreshTimer != null) startRefreshTimer();
    }
}

export default {
    state,
    mutations,
}